@@ -1,25 +1,25 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
-# Copyright (c) 2013 - 2019 PyTroll Community
-
+#
+# Copyright (c) 2013 - 2021 Pytroll developers
+#
 # Author(s):
-
+#
 #   Joonas Karjalainen <joonas.karjalainen@fmi.fi>
 #   Panu Lahtinen <panu.lahtinen@fmi.fi>
 #   Martin Raspaud <martin.raspaud@smhi.se>
 #   Adam Dybbroe <adam.dybbroe@smhi.se
-
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
-
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-
+#
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
@@ -29,33 +29,24 @@
 import argparse
 import sys
 import time
-from six.moves.configparser import RawConfigParser
+from configparser import RawConfigParser
 import logging
 import logging.config
 import os.path
-import datetime as dt
 
 from posttroll.publisher import NoisyPublisher
 from posttroll.message import Message
 from trollsift import Parser
-
-LOGGER = logging.getLogger(__name__)
-
-try:
-    # Python 2
-    str_or_unicode = (str, unicode)
-except NameError:
-    # Pyton 3
-    str_or_unicode = (str, bytes)
-
 from pytroll_collectors.trigger import AbstractWatchDogProcessor
 
+logger = logging.getLogger(__name__)
+
 
 class FilePublisher(AbstractWatchDogProcessor):
 
     def __init__(self, config):
         self.config = config.copy()
-        if isinstance(config["filepattern"], str_or_unicode):
+        if isinstance(config["filepattern"], (str, bytes)):
             self.config["filepattern"] = [self.config["filepattern"]]
 
         self.parsers = [Parser(filepattern)
@@ -65,7 +56,7 @@ class FilePublisher(AbstractWatchDogProcessor):
 
         self.topic = self.config["topic"]
         self.tbus_orbit = self.config.get("tbus_orbit", False)
-        LOGGER.debug("Looking for: %s", str(
+        logger.debug("Looking for: %s", str(
             [parser.globify() for parser in self.parsers]))
         AbstractWatchDogProcessor.__init__(self,
                                            [parser.globify()
@@ -96,7 +87,7 @@ class FilePublisher(AbstractWatchDogProcessor):
     def process(self, pathname):
         '''Process the event'''
         # New file created and closed
-        LOGGER.debug("processing %s", pathname)
+        logger.debug("processing %s", pathname)
         # parse information and create self.info dict{}
         metadata = self.config.copy()
         success = False
@@ -108,14 +99,14 @@ class FilePublisher(AbstractWatchDogProcessor):
             except ValueError:
                 pass
             if not success:
-                LOGGER.warning("Could not find a matching pattern for %s",
+                logger.warning("Could not find a matching pattern for %s",
                                pathname)
 
         metadata['uri'] = pathname
         metadata['uid'] = os.path.basename(pathname)
 
         if self.tbus_orbit and "orbit_number" in metadata:
-            LOGGER.info("Changing orbit number by -1!")
+            logger.info("Changing orbit number by -1!")
             metadata["orbit_number"] -= 1
 
         # replace values with corresponding aliases, if any are given
@@ -125,7 +116,7 @@ class FilePublisher(AbstractWatchDogProcessor):
                     metadata[key] = self.aliases[key][str(metadata[key])]
 
         message = Message(self.topic, 'file', metadata)
-        LOGGER.info("Publishing message %s" % str(message))
+        logger.info("Publishing message %s" % str(message))
         self.pub.send(str(message))
 
 
@@ -185,7 +176,7 @@ def main():
 
     args_dict = vars(args)
     args_dict = {k: args_dict[k]
-                 for k in args_dict if args_dict[k] != None}
+                 for k in args_dict if args_dict[k] is not None}
 
     config = {}
 
@@ -218,7 +209,7 @@ def main():
         except AttributeError:
             loglevel = logging.DEBUG
 
-        LOGGER.setLevel(loglevel)
+        logger.setLevel(loglevel)
         rootlogger = logging.getLogger("")
         rootlogger.setLevel(loglevel)
         strhndl = logging.StreamHandler()
@@ -231,7 +222,7 @@ def main():
     else:
         logging.config.fileConfig(log_config)
 
-    LOGGER.debug("Logger started")
+    logger.debug("Logger started")
 
     # Start watching for new files
     notifier = FilePublisher(config)
@@ -241,12 +232,12 @@ def main():
         while True:
             time.sleep(6000000)
     except KeyboardInterrupt:
-        LOGGER.info("Interrupting TrollStalker")
+        logger.info("Interrupting TrollStalker")
     finally:
         notifier.stop()
 
 
 if __name__ == "__main__":
     # LOGGER = logging.getLogger("trollstalker")
-    LOGGER = logging.getLogger("trollstalker")
+    logger = logging.getLogger("trollstalker")
     main()
