@@ -1,22 +1,22 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
-# Copyright (c) 2018 PyTroll team
-
+#
+# Copyright (c) 2018 - 2021 Pytroll developers
+#
 # Author(s):
-
-#   panu.lahtinen@fmi.fi
-
+#
+#   Panu Lahtinen <panu.lahtinen@fmi.fi>
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
-
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-
+#
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
@@ -27,7 +27,7 @@ import logging
 import os
 import os.path
 import unittest
-from unittest.mock import patch, MagicMock
+from unittest.mock import patch, MagicMock, call
 
 import pytest
 
@@ -49,6 +49,7 @@ CONFIG_INI_NO_SEG = ini_to_dict(os.path.join(THIS_DIR, "data/segments.ini"),
                                 "goes16")
 CONFIG_INI_HIMAWARI = ini_to_dict(os.path.join(THIS_DIR, "data/segments.ini"),
                                   "himawari-8")
+LOGGING_ERROR = logging.ERROR
 
 
 class FakeMessage:
@@ -104,6 +105,7 @@ class TestSegmentGatherer(unittest.TestCase):
         self.hrpt_pps = SegmentGatherer(CONFIG_NO_SEG)
         self.msg_ini = SegmentGatherer(CONFIG_INI)
         self.goes_ini = SegmentGatherer(CONFIG_INI_NO_SEG)
+        self.himawari_ini = SegmentGatherer(CONFIG_INI_HIMAWARI)
 
     def test_init(self):
         """Test init."""
@@ -496,6 +498,8 @@ class TestSegmentGatherer(unittest.TestCase):
         self.assertTrue('posttroll' in config)
         self.assertTrue('time_tolerance' in config)
         self.assertTrue('timeliness' in config)
+        self.assertTrue('time_name' in config)
+        self.assertTrue('check_existing_files_after_start' in config)
 
         self.assertTrue('topics' in config['posttroll'])
         self.assertTrue('nameservers' in config['posttroll'])
@@ -557,6 +561,112 @@ class TestSegmentGatherer(unittest.TestCase):
         publish_service_name = col._generate_publish_service_name()
         self.assertEqual(publish_service_name, "segment_gatherer_iodc_msg")
 
+    @patch("pytroll_collectors.segments.logging")
+    @patch("pytroll_collectors.segments.glob")
+    def test_check_and_add_existing_files(self, glob, logging):
+        """Test that existing matching files are added to the slot."""
+        existing_files = [
+            "/home/lahtinep/data/satellite/geo/msg/H-000-MSG3__-MSG3________-VIS006___-000007___-201611281100-__",
+            "/home/lahtinep/data/satellite/geo/msg/H-000-MSG3__-MSG3________-VIS006___-000008___-201611281100-__",
+            # A file that should not match
+            "/home/lahtinep/data/satellite/geo/msg/H-000-MSG4__-MSG4________-VIS006___-000008___-201611281100-__"]
+        glob.glob.return_value = existing_files
+        mda = self.mda_msg0deg.copy()
+        fake_message = FakeMessage(mda)
+        message = Message(fake_message, self.msg0deg._patterns['msg'])
+        self.msg0deg._create_slot(message)
+        slot_str = str(mda["start_time"])
+        slot = self.msg0deg.slots[slot_str]
+        self.msg0deg._config['check_existing_files_after_start'] = True
+
+        self.msg0deg.check_and_add_existing_files(slot, message)
+        assert call(logging.DEBUG) in logging.disable.mock_calls
+        assert call(logging.NOTSET) in logging.disable.mock_calls
+        assert logging.disable.call_count == 2
+        for fname in existing_files[:-1]:
+            assert os.path.basename(fname) in slot._info['msg']['received_files']
+        assert os.path.basename(existing_files[-1]) not in slot._info['msg']['received_files']
+
+        # For the next message(s) the existing files should not be handled
+        existing_files = [
+            "/home/lahtinep/data/satellite/geo/msg/H-000-MSG3__-MSG3________-VIS006___-000005___-201611281100-__",
+            "/home/lahtinep/data/satellite/geo/msg/H-000-MSG3__-MSG3________-VIS006___-000006___-201611281100-__"]
+        glob.glob.return_value = existing_files
+        self.msg0deg.check_and_add_existing_files(slot, message)
+        for fname in existing_files[:-1]:
+            assert os.path.basename(fname) not in slot._info['msg']['received_files']
+        assert logging.disable.call_count == 2
+
+        # Messages with other types than 'file' should be ignored
+        message.type = "collection"
+        self.msg0deg._is_first_message_after_start = True
+        with self._caplog.at_level(LOGGING_ERROR):
+            self.msg0deg.check_and_add_existing_files(slot, message)
+            logs = [rec.message for rec in self._caplog.records]
+            assert "Only 'file' messages are supported." in logs
+        assert logging.disable.call_count == 2
+
+    def test_messaging(self):
+        """Test that messaging is initialized correctly."""
+        with patch('pytroll_collectors.utils.create_publisher_from_dict_config') as creator:
+            with patch('pytroll_collectors.segments.ListenerContainer') as ListenerContainer:
+                self.msg_ini._setup_messaging()
+        assert_messaging('segment_gatherer_msg', 0, None, None, creator, ListenerContainer)
+
+    def test_messaging_disable_nameservers(self):
+        """Test that messaging is initialized correctly when nameserver connections are disabled."""
+        with patch('pytroll_collectors.utils.create_publisher_from_dict_config') as creator:
+            with patch('pytroll_collectors.segments.ListenerContainer') as ListenerContainer:
+                self.goes_ini._setup_messaging()
+        assert_messaging('segment_gatherer_goes16', '12345', False, False, creator, ListenerContainer)
+
+    def test_messaging_multiple_nameservers(self):
+        """Test that messaging is initialized correctly when nameserver connections are disabled."""
+        with patch('pytroll_collectors.utils.create_publisher_from_dict_config') as creator:
+            with patch('pytroll_collectors.segments.ListenerContainer') as ListenerContainer:
+                self.himawari_ini._setup_messaging()
+        assert_messaging('segment_gatherer_himawari-8', 0, ['localhost', 'otherserver'],
+                         'localhost', creator, ListenerContainer)
+
+    def test_publisher_disable_nameservers_multiple_nameservers(self):
+        """Test that messaging is initialized correctly when nameserver connections are disabled."""
+        with patch('pytroll_collectors.utils.create_publisher_from_dict_config') as creator:
+            self.msg0deg._setup_publisher()
+        assert_messaging('segment_gatherer_msg', 0, False, None, creator, None)
+
+    def test_listener_use_first_nameserver(self):
+        """Test that listener usest the first nameserver when multiple are given."""
+        with patch('pytroll_collectors.segments.ListenerContainer') as ListenerContainer:
+            self.msg0deg._setup_listener()
+        assert_messaging(None, None, None, 'localhost', None, ListenerContainer)
+
+
+def assert_messaging(name, port, publisher_nameservers, listener_nameserver, creator, listener_container):
+    """Test messaging settings."""
+    if creator:
+        _assert_creator(name, port, publisher_nameservers, creator)
+    if listener_container:
+        _assert_listener_container(listener_container, listener_nameserver)
+
+
+def _assert_creator(name, port, publisher_nameservers, creator):
+    expected_publisher = {
+        'name': name,
+        'port': port,
+        'nameservers': publisher_nameservers,
+    }
+    creator.assert_called_with(expected_publisher)
+    creator.return_value.start.assert_called_once()
+
+
+def _assert_listener_container(listener_container, listener_nameserver):
+    listener_container.assert_called_once_with(
+        topics=['/foo/bar'],
+        addresses=None,
+        nameserver=listener_nameserver,
+        services='',
+    )
+
 
 viirs_message = (
     'pytroll://foo/viirs/segment/SDR/1B/polar/direct_readout dataset safusr.u@lxserv1043.smhi.se '
